简体中文 | [[EN](https://github.com/szuboy/paddle-nnUNet/blob/master/README_EN.md)]

<div align="center">

<p align="center">
    <img src="https://github.com/szuboy/paddle-nnUNet/blob/master/paddlennunet.png?raw=true" align="middle" width="450"/>
</p>

**飞桨nnUNet医学图像分割框架，一个基于PaddlePaddle翻译的nnUNet全新版本！**

![Build Status](https://github.com/szuboy/paddle-nnUNet/actions/workflows/python-package.yml/badge.svg)
[![License](https://img.shields.io/badge/license-Apache%202-blue.svg)](LICENSE)
![python version](https://img.shields.io/badge/python-3.0+-orange.svg)
![support os](https://img.shields.io/badge/os-linux%2C%20win%2C%20mac-yellow.svg)
![PyPI Status](https://pepy.tech/badge/paddle-nnunet/month)
</div>

## nnUNet

UNet几乎是卷积神经网络在医学图像分割领域的基线模型，同样地出现了许多基于UNet的改进版本，比如：V-Net和UNet++。作为一个自适应框架，nnUNet无疑是所有改进和优化模型中最成功的一个。nnUNet已经有[Pytorch版本](https://github.com/MIC-DKFZ/nnUNet) ，而这是对应的PaddlePaddle版本。如果想了解nnU-Net的更多信息，请阅读发布的[论文](https://www.nature.com/articles/s41592-020-01008-z) 。

## 安装方式

待补充

## 使用教程

### 数据转换

待补充

### 实验计划和预处理

待补充

### 模型的训练

待补充

### 详细的教程推荐

如果你还想了解更详细的教程解析，请参考[ReadTheDocs教程](https://paddle-nnunet.readthedocs.io/) ，这里啥都有讲！可用性不够好？也请让我们知道！

## 许可证书
本项目的发布受Apache 2.0 license许可认证。
